searchNodes=[{"doc":"SafeURL is library for mitigating Server Side Request Forgery vulnerabilities in Elixir. Private/reserved IP addresses are blacklisted by default, and users can add additional CIDR ranges to blacklist, or alternatively whitelist specific CIDR ranges to which the application is allowed to make requests. You can use allowed?/2 or validate/2 to check if a URL is safe to call, or just call it directly via get/4 which will validate it automatically before calling, and return an error if it is not. Examples iex&gt; SafeURL . allowed? ( &quot;https://includesecurity.com&quot; ) true iex&gt; SafeURL . validate ( &quot;http://google.com/&quot; , schemes : ~w[https] ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://230.10.10.10/&quot; , blacklist_reserved : false ) :ok iex&gt; SafeURL . get ( &quot;https://10.0.0.1/ssrf.txt&quot; ) { :error , :restricted } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; ) { :ok , % HTTPoison.Response { ... } } Options SafeURL can be configured to customize and override validation behaviour by passing the following options: :blacklist_reserved - Blacklist reserved/private IP ranges. Defaults to true . :blacklist - List of CIDR ranges to blacklist. This is additive with :blacklist_reserved . Defaults to [] . :whitelist - List of CIDR ranges to whitelist. If specified, blacklists will be ignored. Defaults to [] . :schemes - List of allowed URL schemes. Defaults to [&quot;http, &quot;https&quot;] . If :blacklist_reserved is true and additional hosts/ranges are supplied with :blacklist , both of them are included in the final blacklist to validate the address. If whitelisted ranges are supplied with :whitelist , all blacklists are ignored and any hosts not explicitly declared in the whitelist are rejected. These options can be set globally in your config.exs file: config :safeurl , blacklist_reserved : true , blacklist : ~w[100.0.0.0/16] , schemes : ~w[https] Or they can be passed to the function directly, overriding any global options if set: iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; , blacklist_reserved : false ) :ok iex&gt; SafeURL . validate ( &quot;https://app.service/&quot; , whitelist : ~w[170.0.0.0/24] ) :ok iex&gt; SafeURL . validate ( &quot;https://app.service/&quot; , blacklist : ~w[170.0.0.0/24] ) { :error , :restricted }","ref":"SafeURL.html","title":"SafeURL","type":"module"},{"doc":"Validate a string URL against a blacklist or whitelist. This method checks if a URL is safe to be called by looking at its scheme and resolved IP address, and matching it against reserved CIDR ranges, and any provided whitelist/blacklist. Returns true if the URL meets the requirements, false otherwise. Examples iex&gt; SafeURL . allowed? ( &quot;https://includesecurity.com&quot; ) true iex&gt; SafeURL . allowed? ( &quot;http://10.0.0.1/&quot; ) false iex&gt; SafeURL . allowed? ( &quot;http://10.0.0.1/&quot; , whitelist : ~w[10.0.0.0/8] ) true Options See Options section above.","ref":"SafeURL.html#allowed?/2","title":"SafeURL.allowed?/2","type":"function"},{"doc":"Validate a URL and execute a GET request using HTTPoison . If the URL is safe, this function will execute the request using HTTPoison , returning the result directly. Otherwise, it will return {:error, :restricted} . headers and httpoison_options will be passed directly to HTTPoison when the request is executed. See allowed?/2 for more details on URL validation. Examples iex&gt; SafeURL . get ( &quot;https://10.0.0.1/ssrf.txt&quot; ) { :error , :restricted } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; ) { :ok , % HTTPoison.Response { ... } } iex&gt; SafeURL . get ( &quot;https://google.com/&quot; , schemes : ~w[ftp] ) { :error , :restricted } Options See Options section above.","ref":"SafeURL.html#get/4","title":"SafeURL.get/4","type":"function"},{"doc":"Alternative method of validating a URL, returning atoms instead of booleans. This calls allowed?/2 underneath to check if a URL is safe to be called. If it is, it returns :ok , otherwise {:error, :restricted} . Examples iex&gt; SafeURL . validate ( &quot;https://includesecurity.com&quot; ) :ok iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; ) { :error , :restricted } iex&gt; SafeURL . validate ( &quot;http://10.0.0.1/&quot; , whitelist : ~w[10.0.0.0/8] ) :ok Options See Options section above.","ref":"SafeURL.html#validate/2","title":"SafeURL.validate/2","type":"function"},{"doc":"SafeURL is a library that aids developers in protecting against a class of vulnerabilities known as Server Side Request Forgery. It does this by validating a URL against a configurable white or black list before making an HTTP request. SafeURL is open-source and licensed under MIT. This library was originally created by Nick Fox at Include Security , with substantial improvements contributed by the Slab team. As of January 2022, this library is now maintained by Slab.","ref":"readme.html","title":"SafeURL","type":"extras"},{"doc":"This package is not yet available in hex, so it must be installed from GitHub by adding the following to mix.exs : def deps do [ { :safeurl , github : &quot;includesecurity/elixir-safeurl&quot; } ] end","ref":"readme.html#installation","title":"SafeURL - Installation","type":"extras"},{"doc":"SafeURL wraps around HTTPoison and works by resolving the IP address from a supplied URL and validating it against a blacklist or whitelist before sending the request. By default, all internal/reserved CIDR ranges are blacklisted, and developers can add additional CIDR ranges to these lists with the :blacklist parameter, or instead use a whitelist approach with :whitelist . # Only block private IP ranges iex&gt; SafeURL . get ( &quot;https://includesecurity.com&quot; ) { :ok , % HTTPoison.Response { ... } } # Blacklist 8.8.0.0/16 in addition to all private ranges iex&gt; SafeURL . get ( &quot;https://includsecurity.com&quot; , blacklist : [ &quot;8.8.0.0/16&quot; ] ) { :ok , % HTTPoison.Response { ... } } # Only allow requests to hosts on 10.0.0.0/24 iex&gt; SafeURL . get ( &quot;https://includesecurity.com&quot; , whitelist : [ &quot;10.0.0.0/24&quot; ] ) { :error , :restricted } # Pass some headers and options to HTTPoison iex&gt; SafeURL . get ( &quot;https://includesecurity.com&quot; , [ ] , [ { &quot;User-Agent&quot; , &quot;elixir/1.11.3&quot; } ] , follow_redirect : false ) If you only need to validate a URL and want to make the request yourself, you can use SafeURL.validate_url() instead: iex&gt; SafeURL . validate_url ( &quot;https://acme.corp.internal&quot; ) { :error , :restricted }","ref":"readme.html#usage","title":"SafeURL - Usage","type":"extras"}]